@@ -7,7 +7,7 @@ RDF::Trine - An RDF Framework for Perl
 
 =head1 VERSION
 
-This document describes RDF::Trine version 1.006
+This document describes RDF::Trine version 1.008
 
 =head1 SYNOPSIS
 
@@ -49,17 +49,29 @@ consists of several components:
 
 =over 4
 
-=item * RDF::Trine::Model - RDF model providing access to a triple store. This module would typically be used to access an existing store by a developer looking to "Just get stuff done."
+=item 
 
-=item * RDF::Trine::Parser - RDF parsers for various serialization formats including RDF/XML, Turtle, RDFa, and RDF/JSON.
+L<RDF::Trine::Model> - RDF model providing access to a triple store. This module would typically be used to access an existing store by a developer looking to "Just get stuff done."
 
-=item * RDF::Trine::Store::Memory - An in-memory, non-persistant triple store. Typically used for temporary data.
+=item 
 
-=item * RDF::Trine::Store::DBI - A triple store for MySQL, PostgreSQL, and SQLite, based on the relational schema used by Redland. Typically used to for large, persistent data.
+L<RDF::Trine::Parser> - RDF parsers for various serialization formats including RDF/XML, Turtle, RDFa, and RDF/JSON.
 
-=item * RDF::Trine::Iterator - Iterator classes for variable bindings and RDF statements, used by RDF::Trine::Store, RDF::Trine::Model, and RDF::Query.
+=item 
 
-=item * RDF::Trine::Namespace - A convenience class for easily constructing RDF::Trine::Node::Resource objects from URI namespaces.
+L<RDF::Trine::Store::Memory> - An in-memory, non-persistant triple store. Typically used for temporary data.
+
+=item 
+
+L<RDF::Trine::Store::DBI> - A triple store for MySQL, PostgreSQL, and SQLite, based on the relational schema used by Redland. Typically used to for large, persistent data.
+
+=item 
+
+L<RDF::Trine::Iterator> - Iterator classes for variable bindings and RDF statements, used by RDF::Trine::Store, RDF::Trine::Model, and RDF::Query.
+
+=item 
+
+L<RDF::Trine::Namespace> - A convenience class for easily constructing RDF::Trine::Node::Resource objects from URI namespaces.
 
 =back
 
@@ -72,11 +84,12 @@ use strict;
 use warnings;
 no warnings 'redefine';
 use Module::Load::Conditional qw[can_load];
+use LWP::UserAgent;
 
 our ($debug, @ISA, $VERSION, @EXPORT_OK);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '1.006';
+	$VERSION	= '1.008';
 	
 	require Exporter;
 	@ISA		= qw(Exporter);
@@ -130,7 +143,7 @@ sub _uniq {
 
 =item C<< iri ( $iri ) >>
 
-Returns a RDF::Trine::Node::Resource object with the given IRI value.
+Returns a L<RDF::Trine::Node::Resource> object with the given IRI value.
 
 =cut
 
@@ -141,7 +154,7 @@ sub iri {
 
 =item C<< blank ( $id ) >>
 
-Returns a RDF::Trine::Node::Blank object with the given identifier.
+Returns a L<RDF::Trine::Node::Blank> object with the given identifier.
 
 =cut
 
@@ -152,7 +165,7 @@ sub blank {
 
 =item C<< literal ( $value, $lang, $dt ) >>
 
-Returns a RDF::Trine::Node::Literal object with the given value and optional
+Returns a L<RDF::Trine::Node::Literal> object with the given value and optional
 language/datatype.
 
 =cut
@@ -163,7 +176,7 @@ sub literal {
 
 =item C<< variable ( $name ) >>
 
-Returns a RDF::Trine::Node::Variable object with the given variable name.
+Returns a L<RDF::Trine::Node::Variable> object with the given variable name.
 
 =cut
 
@@ -174,7 +187,7 @@ sub variable {
 
 =item C<< statement ( @nodes ) >>
 
-Returns a RDF::Trine::Statement object with the supplied node objects.
+Returns a L<RDF::Trine::Statement> object with the supplied node objects.
 
 =cut
 
@@ -189,8 +202,7 @@ sub statement {
 
 =item C<< store ( $config ) >>
 
-Returns a RDF::Trine::Store object based on the supplied configuration string.
-See L<RDF::Trine::Store> for more information on store configuration strings.
+Returns a L<RDF::Trine::Store> object based on the supplied configuration string.
 
 =cut
 
@@ -199,6 +211,28 @@ sub store {
 	return RDF::Trine::Store->new_with_string( $config );
 }
 
+=item C<< default_useragent ( [ $ua ] ) >>
+
+Returns the L<LWP::UserAgent> object used by default for any operation requiring network
+requests. Ordinarily, the calling code will obtain the default user agent, and clone it
+before further configuring it for a specific request, thus leaving the default object
+untouched.
+
+If C<< $ua >> is passed as an argument, sets the global default user agent to this object.
+
+=cut
+
+{ my $_useragent;
+sub default_useragent {
+	my $class	= shift;
+	my $ua		= shift || $_useragent;
+	unless (defined($ua)) {
+		$ua	= LWP::UserAgent->new( agent => "RDF::Trine/$RDF::Trine::VERSION" );
+	}
+	$_useragent	= $ua;
+	return $ua;
+}}
+
 1; # Magic true value required at end of module
 __END__
 
