@@ -7,7 +7,7 @@ RDF::Trine::Model - Model class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Model version 1.006
+This document describes RDF::Trine::Model version 1.008
 
 =head1 METHODS
 
@@ -23,7 +23,7 @@ no warnings 'redefine';
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '1.006';
+	$VERSION	= '1.008';
 }
 
 use Scalar::Util qw(blessed refaddr);
@@ -125,6 +125,22 @@ sub end_bulk_ops {
 	}
 }
 
+=item C<< logger ( [ $logger ] ) >>
+
+Returns the logging object responsible for recording data inserts and deletes.
+
+If C<< $logger >> is passed as an argument, sets the logger to this object.
+
+=cut
+
+sub logger {
+	my $self	= shift;
+	if (scalar(@_)) {
+		$self->{'logger'}	= shift;
+	}
+	return $self->{'logger'};
+}
+
 =item C<< add_statement ( $statement [, $context] ) >>
 
 Adds the specified C<< $statement >> to the rdf store.
@@ -133,7 +149,13 @@ Adds the specified C<< $statement >> to the rdf store.
  
 sub add_statement {
 	my ($self, @args)	= @_;
-	unless ($args[0]->isa('RDF::Trine::Statement')) {
+	if ($args[0]->isa('RDF::Trine::Statement')) {
+		foreach my $n ($args[0]->nodes) {
+			unless (blessed($n) and ($n->isa('RDF::Trine::Node::Resource') or $n->isa('RDF::Trine::Node::Literal') or $n->isa('RDF::Trine::Node::Blank') or $n->isa('RDF::Trine::Node::Nil'))) {
+				throw RDF::Trine::Error::MethodInvocationError -text => 'Cannot add a pattern (non-ground statement) to a model';
+			}
+		}
+	} else {
 		throw RDF::Trine::Error::MethodInvocationError -text => 'Argument is not an RDF::Trine::Statement';
 	}
 	if ($self->{temporary}) {
@@ -155,6 +177,15 @@ sub add_statement {
 # 			warn "*** upgraded to a DBI store";
 		}
 	}
+	
+	if (my $log = $self->logger) {
+		my ($st, $context)	= @args;
+		if (defined($context)) {
+			$st	= RDF::Trine::Statement::Quad->new(($st->nodes)[0..2], $context);
+		}
+		$log->add($st);
+	}
+	
 	return $self->_store->add_statement( @args );
 }
 
@@ -217,13 +248,16 @@ sub add_hashref {
 
 =item C<< add_iterator ( $iter ) >>
 
-Add triples from the statement iteratorto the model.
+Add triples from the statement iterator to the model.
 
 =cut
 
 sub add_iterator {
 	my $self	= shift;
 	my $iter	= shift;
+	unless (blessed($iter) and ($iter->is_graph)) {
+		throw RDF::Trine::Error::MethodInvocationError -text => 'Cannot add a '. ref($iter) . ' iterator to a model, only graphs.';
+	}
 	$self->begin_bulk_ops();
 	while (my $st = $iter->next) {
 		$self->add_statement( $st );
@@ -367,7 +401,15 @@ Removes the specified C<< $statement >> from the rdf store.
 
 sub remove_statement {
 	my $self	= shift;
-	return $self->_store->remove_statement( @_ );
+	my @args	= @_;
+	if (my $log = $self->logger) {
+		my ($st, $context)	= @args;
+		if (defined($context)) {
+			$st	= RDF::Trine::Statement::Quad->new(($st->nodes)[0..2], $context);
+		}
+		$log->delete($st);
+	}
+	return $self->_store->remove_statement( @args );
 }
 
 =item C<< remove_statements ( $subject, $predicate, $object [, $context] ) >>
@@ -378,6 +420,9 @@ Removes all statements matching the supplied C<< $statement >> pattern from the
 
 sub remove_statements {
 	my $self	= shift;
+	if (my $log = $self->logger) {
+		$log->delete($_) foreach (@_);
+	}
 	return $self->_store->remove_statements( @_ );
 }
 
