@@ -7,7 +7,7 @@ RDF::Trine::Parser::Turtle - Turtle RDF Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::Turtle version 1.006
+This document describes RDF::Trine::Parser::Turtle version 1.008
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ use RDF::Trine::Parser::Turtle::Token;
 
 our $VERSION;
 BEGIN {
-	$VERSION				= '1.006';
+	$VERSION				= '1.008';
 	foreach my $ext (qw(ttl)) {
 		$RDF::Trine::Parser::file_extensions{ $ext }	= __PACKAGE__;
 	}
@@ -75,7 +75,7 @@ sub new {
 
 =item C<< parse ( $base_uri, $rdf, \&handler ) >>
 
-Parses the C<< $data >>, using the given C<< $base_uri >>. Calls the
+Parses the bytes in C<< $data >>, using the given C<< $base_uri >>. Calls the
 C<< triple >> method for each RDF triple parsed. This method does nothing by
 default, but can be set by using one of the default C<< parse_* >> methods.
 
@@ -122,10 +122,13 @@ sub parse_file {
 	$self->_parse($l);
 }
 
-=item C<< parse_node ( $string, $base ) >>
+=item C<< parse_node ( $string, $base, [ token => \$token ] ) >>
 
 Returns the RDF::Trine::Node object corresponding to the node whose N-Triples
 serialization is found at the beginning of C<< $string >>.
+If a reference to C<< $token >> is given, it is dereferenced and set to the
+RDF::Trine::Parser::Turtle::Token tokenizer object, allowing access to information such
+as the token's position in the input string.
 
 =cut
 
@@ -133,10 +136,16 @@ sub parse_node {
 	my $self	= shift;
 	my $string	= shift;
 	local($self->{baseURI})	= shift;
+	my %args	= @_;
 	open(my $fh, '<:encoding(UTF-8)', \$string);
 	my $l	= RDF::Trine::Parser::Turtle::Lexer->new($fh);
 	my $t = $self->_next_nonws($l);
-	my $node	= $self->_object($l, $t);
+	return unless ($t);
+	my $node	= $self->_term($l, $t);
+	my $token_ref	= $args{token};
+	if (defined($token_ref) and ref($token_ref)) {
+		$$token_ref	= $t;
+	}
 	return $node;
 }
 
@@ -144,7 +153,9 @@ sub _parse {
 	my $self	= shift;
 	my $l		= shift;
 	$l->check_for_bom;
-	$self->{map}	= RDF::Trine::NamespaceMap->new();
+	unless (exists($self->{map})) {
+		$self->{map}	= RDF::Trine::NamespaceMap->new();
+	}
 	while (my $t = $self->_next_nonws($l)) {
 		$self->_statement($l, $t);
 	}
@@ -195,16 +206,19 @@ sub _statement {
 	my $t		= shift;
 	my $type	= $t->type;
 # 		when (WS) {}
-	if ($type eq PREFIX) {
+	if ($type == PREFIX or $type == SPARQLPREFIX) {
 		$t	= $self->_get_token_type($l, PREFIXNAME);
 		my $name	= $t->value;
 		$name		=~ s/:$//;
 		$t	= $self->_get_token_type($l, IRI);
 		my $r	= RDF::Trine::Node::Resource->new($t->value, $self->{baseURI});
 		my $iri	= $r->uri_value;
-		$t	= $self->_next_nonws($l);
-		if ($t and $t->type != DOT) {
-			$self->_unget_token($t);
+		if ($type == PREFIX) {
+			$t	= $self->_get_token_type($l, DOT);
+# 			$t	= $self->_next_nonws($l);
+# 			if ($t and $t->type != DOT) {
+# 				$self->_unget_token($t);
+# 			}
 		}
 		$self->{map}->add_mapping( $name => $iri );
 		if (my $ns = $self->{namespaces}) {
@@ -213,13 +227,16 @@ sub _statement {
 			}
 		}
 	}
-	elsif ($type eq BASE) {
+	elsif ($type == BASE or $type == SPARQLBASE) {
 		$t	= $self->_get_token_type($l, IRI);
 		my $r	= RDF::Trine::Node::Resource->new($t->value, $self->{baseURI});
 		my $iri	= $r->uri_value;
-		$t	= $self->_next_nonws($l);
-		if ($t and $t->type != DOT) {
-			$self->_unget_token($t);
+		if ($type == BASE) {
+			$t	= $self->_get_token_type($l, DOT);
+# 			$t	= $self->_next_nonws($l);
+# 			if ($t and $t->type != DOT) {
+# 				$self->_unget_token($t);
+# 			}
 		}
 		$self->{baseURI}	= $iri;
 	}
@@ -372,14 +389,13 @@ sub _assert_triple {
 	}
 }
 
-
 sub _object {
 	my $self	= shift;
 	my $l		= shift;
 	my $t		= shift;
+	my $type	= $t->type;
 	my $tcopy	= $t;
 	my $obj;
-	my $type	= $t->type;
 	if ($type==LBRACKET) {
 		$obj	= RDF::Trine::Node::Blank->new();
 		my $t	= $self->_next_nonws($l);
@@ -415,27 +431,38 @@ sub _object {
 	} elsif (not($type==IRI or $type==PREFIXNAME or $type==STRING1D or $type==STRING3D or $type==STRING1S or $type==STRING3S or $type==BNODE or $type==INTEGER or $type==DECIMAL or $type==DOUBLE or $type==BOOLEAN)) {
 		$self->_throw_error("Expecting object but got " . decrypt_constant($type), $t, $l);
 	} else {
-		if ($type==STRING1D or $type==STRING3D or $type==STRING1S or $type==STRING3S) {
-			my $value	= $t->value;
-			my $t		= $self->_next_nonws($l);
-			my $dt;
-			my $lang;
-			if ($t) {
-				if ($t->type == HATHAT) {
-					my $t		= $self->_next_nonws($l);
-					if ($t->type == IRI or $t->type == PREFIXNAME) {
-						$dt	= $self->_token_to_node($t);
-					}
-				} elsif ($t->type == LANG) {
-					$lang	= $t->value;
-				} else {
-					$self->_unget_token($t);
+		$obj		= $self->_term($l, $t);
+	}
+	return $obj;
+}
+
+sub _term {
+	my $self	= shift;
+	my $l		= shift;
+	my $t		= shift;
+	my $tcopy	= $t;
+	my $obj;
+	my $type	= $t->type;
+	if ($type==STRING1D or $type==STRING3D or $type==STRING1S or $type==STRING3S) {
+		my $value	= $t->value;
+		my $t		= $self->_next_nonws($l);
+		my $dt;
+		my $lang;
+		if ($t) {
+			if ($t->type == HATHAT) {
+				my $t		= $self->_next_nonws($l);
+				if ($t->type == IRI or $t->type == PREFIXNAME) {
+					$dt	= $self->_token_to_node($t);
 				}
+			} elsif ($t->type == LANG) {
+				$lang	= $t->value;
+			} else {
+				$self->_unget_token($t);
 			}
-			$obj	= RDF::Trine::Node::Literal->new($value, $lang, $dt);
-		} else {
-			$obj	= $self->_token_to_node($t, $type);
 		}
+		$obj	= RDF::Trine::Node::Literal->new($value, $lang, $dt);
+	} else {
+		$obj	= $self->_token_to_node($t, $type);
 	}
 	return $obj;
 }
