@@ -7,7 +7,7 @@ RDF::Trine::Parser::Turtle::Lexer - Tokenizer for parsing Turtle, TriG, and N-Tr
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::Turtle::Lexer version 1.006
+This document describes RDF::Trine::Parser::Turtle::Lexer version 1.008
 
 =head1 SYNOPSIS
 
@@ -35,7 +35,7 @@ use RDF::Trine::Error;
 
 our $VERSION;
 BEGIN {
-	$VERSION				= '1.006';
+	$VERSION				= '1.008';
 }
 
 my $r_nameChar_extra		= qr'[-0-9\x{B7}\x{0300}-\x{036F}\x{203F}-\x{2040}]'o;
@@ -47,10 +47,13 @@ my $r_nameChar_test			= qr"(?:$r_nameStartChar|$r_nameChar_extra)";
 my $r_double				= qr'[+-]?([0-9]+\.[0-9]*[eE][+-]?[0-9]+|\.[0-9]+[eE][+-]?[0-9]+|[0-9]+[eE][+-]?[0-9]+)';
 my $r_decimal				= qr'[+-]?(([0-9]+\.[0-9]+)|\.([0-9])+)';
 my $r_integer				= qr'[+-]?[0-9]+';
+my $r_PN_CHARS_U			= qr/[_A-Za-z_\x{00C0}-\x{00D6}\x{00D8}-\x{00F6}\x{00F8}-\x{02FF}\x{0370}-\x{037D}\x{037F}-\x{1FFF}\x{200C}-\x{200D}\x{2070}-\x{218F}\x{2C00}-\x{2FEF}\x{3001}-\x{D7FF}\x{F900}-\x{FDCF}\x{FDF0}-\x{FFFD}\x{10000}-\x{EFFFF}]/;
+my $r_PN_CHARS				= qr"${r_PN_CHARS_U}|[-0-9\x{00B7}\x{0300}-\x{036F}\x{203F}-\x{2040}]";
+my $r_bnode_id				= qr"(?:${r_PN_CHARS_U}|[0-9])((${r_PN_CHARS}|[.])*${r_PN_CHARS})?";
 
 my $r_PN_CHARS_BASE			= qr/([A-Z]|[a-z]|[\x{00C0}-\x{00D6}]|[\x{00D8}-\x{00F6}]|[\x{00F8}-\x{02FF}]|[\x{0370}-\x{037D}]|[\x{037F}-\x{1FFF}]|[\x{200C}-\x{200D}]|[\x{2070}-\x{218F}]|[\x{2C00}-\x{2FEF}]|[\x{3001}-\x{D7FF}]|[\x{F900}-\x{FDCF}]|[\x{FDF0}-\x{FFFD}]|[\x{10000}-\x{EFFFF}])/;
-my $r_PN_CHARS_U			= qr/([_]|${r_PN_CHARS_BASE})/;
-my $r_PN_CHARS				= qr/${r_PN_CHARS_U}|-|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}]/;
+# my $r_PN_CHARS_U			= qr/([_]|${r_PN_CHARS_BASE})/;
+# my $r_PN_CHARS				= qr/${r_PN_CHARS_U}|-|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}]/;
 my $r_PN_PREFIX				= qr/(${r_PN_CHARS_BASE}((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/;
 my $r_PN_LOCAL_ESCAPED		= qr{(\\([-~.!&'()*+,;=/?#@%_\$]))|%[0-9A-Fa-f]{2}};
 my $r_PN_LOCAL				= qr/((${r_PN_CHARS_U}|[:0-9]|${r_PN_LOCAL_ESCAPED})((${r_PN_CHARS}|${r_PN_LOCAL_ESCAPED}|[:.])*(${r_PN_CHARS}|[:]|${r_PN_LOCAL_ESCAPED}))?)/;
@@ -198,7 +201,7 @@ sub get_token {
 			next;
 		}
 		elsif ($c =~ /[A-Za-z\x{00C0}-\x{00D6}\x{00D8}-\x{00F6}\x{00F8}-\x{02FF}\x{0370}-\x{037D}\x{037F}-\x{1FFF}\x{200C}-\x{200D}\x{2070}-\x{218F}\x{2C00}-\x{2FEF}\x{3001}-\x{D7FF}\x{F900}-\x{FDCF}\x{FDF0}-\x{FFFD}\x{10000}-\x{EFFFF}]/) {
-			if ($self->{buffer} =~ /^a(?!:)\b/) {
+			if ($self->{buffer} =~ /^a(?!:)\s/) {
 				$self->_get_char;
 				return $self->new_token(A);
 			} elsif ($self->{buffer} =~ /^(?:true|false)(?!:)\b/) {
@@ -206,10 +209,10 @@ sub get_token {
 				return $self->new_token(BOOLEAN, $bool);
 			} elsif ($self->{buffer} =~ /^BASE(?!:)\b/i) {
 				$self->_read_length(4);
-				return $self->new_token(BASE);
+				return $self->new_token(SPARQLBASE);
 			} elsif ($self->{buffer} =~ /^PREFIX(?!:)\b/i) {
 				$self->_read_length(6);
-				return $self->new_token(PREFIX);
+				return $self->new_token(SPARQLPREFIX);
 			} else {
 				return $self->_get_pname;
 			}
@@ -360,7 +363,7 @@ sub _get_pname {
 	my $self	= shift;
 	my $prefix	= '';
 	
-	if ($self->{buffer} =~ $r_PNAME_LN) {
+	if ($self->{buffer} =~ /^$r_PNAME_LN/) {
 		my $ln	= $self->_read_length($+[0]);
 		my ($ns,$local)	= ($ln =~ /^([^:]*:)(.*)$/);
 		no warnings 'uninitialized';
@@ -419,8 +422,8 @@ sub _get_iriref {
 sub _get_bnode {
 	my $self	= shift;
 	$self->_read_word('_:');
-	unless ($self->{buffer} =~ /^${r_nameStartChar}(?:${r_nameStartChar}|${r_nameChar_extra})*/o) {
-		$self->_error("Expected: name");
+	unless ($self->{buffer} =~ /^${r_bnode_id}/o) {
+		$self->_throw_error("Expected: name");
 	}
 	my $name	= substr($self->{buffer}, 0, $+[0]);
 	$self->_read_word($name);
