@@ -7,7 +7,7 @@ RDF::Trine::Statement::Quad - Class for quads and quad patterns
 
 =head1 VERSION
 
-This document describes RDF::Trine::Statement::Quad version 1.006
+This document describes RDF::Trine::Statement::Quad version 1.008
 
 =cut
 
@@ -25,7 +25,7 @@ use Carp qw(croak);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '1.006';
+	$VERSION	= '1.008';
 }
 
 ######################################################################
@@ -82,9 +82,11 @@ sub node_names {
 	return qw(subject predicate object context);
 }
 
+=item C<< graph >>
+
 =item C<< context >>
 
-Returns the context node of the quad pattern.
+Returns the graph node of the quad pattern.
 
 =cut
 
@@ -95,6 +97,7 @@ sub context {
 	}
 	return $self->[3];
 }
+*graph	= \&context;
 
 =item C<< sse >>
 
