@@ -4,11 +4,19 @@ RDF::Trine::Store::DBI::SQLite - SQLite subclass of DBI store
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::DBI::SQLite version 1.006
+This document describes RDF::Trine::Store::DBI::SQLite version 1.008
 
 =head1 SYNOPSIS
 
     use RDF::Trine::Store::DBI::SQLite;
+    my $store = RDF::Trine::Store->new({
+                                         storetype => 'DBI',
+                                         name      => 'test',
+                                         dsn       => "dbi:SQLite:dbname=test.db",
+                                         username  => '',
+                                         password  => ''
+                                       });
+
 
 =head1 DESCRIPTION
 
@@ -26,7 +34,7 @@ use Scalar::Util qw(blessed reftype refaddr);
 
 our $VERSION;
 BEGIN {
-	$VERSION	= "1.006";
+	$VERSION	= "1.008";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 }
