@@ -4,7 +4,7 @@ RDF::Trine::Store::Memory - Simple in-memory RDF store
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::Memory version 1.006
+This document describes RDF::Trine::Store::Memory version 1.008
 
 =head1 SYNOPSIS
 
@@ -23,6 +23,7 @@ use warnings;
 no warnings 'redefine';
 use base qw(RDF::Trine::Store);
 
+use Encode;
 use Set::Scalar;
 use Data::Dumper;
 use Digest::SHA;
@@ -38,7 +39,7 @@ use RDF::Trine::Error;
 my @pos_names;
 our $VERSION;
 BEGIN {
-	$VERSION	= "1.006";
+	$VERSION	= "1.008";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 	@pos_names	= qw(subject predicate object context);
@@ -417,7 +418,7 @@ sub add_statement {
 	if ($count == 0) {
 		$self->{size}++;
 		my $id	= scalar(@{ $self->{ statements } });
-		$self->{hash}->add('+' . $st->as_string);
+		$self->{hash}->add('+' . encode_utf8($st->as_string));
 		push( @{ $self->{ statements } }, $st );
 		foreach my $pos (0 .. $#pos_names) {
 			my $name	= $pos_names[ $pos ];
@@ -474,7 +475,7 @@ sub remove_statement {
 		$self->{size}--;
 		my $id	= $self->_statement_id( $st->nodes );
 # 		warn "removing statement $id: " . $st->as_string . "\n";
-		$self->{hash}->add('-' . $st->as_string);
+		$self->{hash}->add('-' . encode_utf8($st->as_string));
 		$self->{statements}[ $id ]	= undef;
 		foreach my $pos (0 .. 3) {
 			my $name	= $pos_names[ $pos ];
